import { LitElement, TemplateResult } from 'lit';
/**
 * The TinyMCE editing mode.
 */
export declare enum EditingMode {
    /** Full editor mode. */
    Classic = "classic",
    /** Distraction free mode. */
    DistractionFree = "distraction-free"
}
/**
 * An element wrapping the TinyMCE editor.
 *
 * @example
 *
 * Renders a Rich Text Editor in distraction free mode with a link, unlink and a media picker button on the toolbar and the max size of the image inserted of 200.
 *
 * ```html
 * <umbh-tinymce mode="distraction-free" maximagesize="200" toolbar='["link", "unlink", "umbmediapicker"]'></umbh-tinymce>
 * ```
 *
 * @remarks
 * Cannot be used inside ShadowDom.
 */
export default class TinyMceElement extends LitElement {
    #private;
    /** Max size of image when inserted. */
    maxImageSize: number;
    /** The editing mode. */
    mode: EditingMode;
    /** Stylesheets to load, must be the name of the stylesheet from the stylesheets tree without the `.css` extension.. */
    stylesheets: string[];
    /** The tooblar options. */
    toolbar: string[];
    /** The value */
    value?: string;
    constructor();
    /** @ignore */
    createRenderRoot(): HTMLElement;
    /** @ignore */
    connectedCallback(): void;
    /** @ignore */
    willUpdate(changedProperties: Map<PropertyKey, unknown>): void;
    /** @ignore */
    render(): TemplateResult;
}
//# sourceMappingURL=index.d.ts.map