import { editorService } from '../../base/angular';
/**
 * @example
 *
 * ```js
 * import mediaPicker from '@umbraco/headless-backoffice-bridge/pickers/media'
 *
 * mediaPicker.show({
 *   multiple: true,
 *   onlyImages: true,
 *   submit(items) => {
 *     // do something with the selected items
 *   }
 * })
 * ```
 */
export default {
    /**
     * Shows the Media Picker.
     *
     * @param config - The Media Picker Configuration.
     */
    show: (config) => editorService.mediaPicker({
        allowMediaEdit: config.allowMediaEdit,
        cropSize: config.cropSize,
        currentTarget: config.target,
        disableFocalPoint: config.disableFocalPoint,
        disableFolderSelect: config.disableFolderSelect,
        startNodeId: config.startMedia,
        multiPicker: config.multiple,
        onlyImages: config.onlyImages,
        onlyFolders: config.onlyFolders,
        showDetails: config.showDetails,
        close: () => {
            editorService.close();
        },
        submit: (model) => {
            editorService.close();
            config.submit(model.selection.map((item) => ({
                altText: item.altText,
                caption: item.caption,
                coordinates: item.coordinates,
                focalPoint: item.focalPoint,
                udi: item.udi
            })));
        }
    })
};
//# sourceMappingURL=index.js.map